@@ -23,7 +23,7 @@ def get_group(pid, groups):
     group_out = "no_group"
     try:
         for group in groups:
-            if pid in groups[group]:
+            if str(pid) in groups[group]:
                 group_out = group
     except Exception:
         pass
