@@ -3,11 +3,8 @@ import os
 import re
 import sys
 
-import numpy as np
 import pandas as pd
 import requests
-from numpy import argmax, exp, log
-from numpy.random import multinomial
 
 ERR_SYS = "\nSystem error: "
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
@@ -15,16 +12,35 @@ URL_MS_MODELOS = os.getenv("URL_MS_MODELOS", None)
 
 
 def delete_file_dataframe(file_to_send, file_send):
+    """
+    this function delete temporal files send to ms_modelos
+
+    Parameters
+    ----------
+    file_to_send : TYPE
+        DESCRIPTION.
+    file_send : TYPE
+        DESCRIPTION.
+
+    Returns
+    -------
+    None.
+
+    """
     try:
         file_send["model_json"].close()
         os.remove(file_to_send) if os.path.exists(file_to_send) else None
     except OSError as error:
         print("Error con eliminacion archivo" + error)
-    except Exception as e:
-        print("Error con eliminacion archivo" + e)
+    except Exception as e_1:
+        print("Error con eliminacion archivo" + e_1)
 
 
 class CleanText:
+    """
+    this function clean and prepare text to analysis
+    """
+
     def __init__(self, input_txt, verbose=False):
         """
         This functions validates if the input of the class is a string.
@@ -38,16 +54,32 @@ class CleanText:
             verbose: bool
             If True prints when the input is not a string.
         """
-        METHOD_NAME = "init"
+        method_name = "__init__"
+
+        self.bad_words = ["de", "que", "la", "los", "el", "las"]
+        with open(BASE_DIR + "/common/stopwords/English.txt", "r") as file:
+            self.stopwords = file.read().splitlines()
+        self.bad_words.extend(self.stopwords)
+        with open(BASE_DIR + "/common/stopwords/Spanish.txt", "r") as file:
+            self.stopwords = file.read().splitlines()
+        self.bad_words.extend(self.stopwords)
+
         if type(input_txt) == str:
             self.input_txt = input_txt
         else:
-            print(f'WARNING: Input {input_txt} is not a string. Default set to "".')
-            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+            if verbose:
+                print(f'WARNING: Input {input_txt} is not a string. Default set to "".')
+                print(f"Class: {self.__str__()}\nMethod: {method_name}")
             self.input_txt = ""
 
     def process_text(
-        self, rts=False, mentions=False, hashtags=False, links=False, spec_chars=False
+        self,
+        rts=False,
+        mentions=False,
+        hashtags=False,
+        links=False,
+        spec_chars=False,
+        stop_words=True,
     ):
         """
         This functions cleans the input text.
@@ -72,13 +104,16 @@ class CleanText:
             type: bool
             If True all special characters (except accents, # and @) are removed
             from the text, default=False.
+        stop_words:
+            type: bool
+            If True stop_words are removed from the, text, default=True.
 
         Returns
         -------
         str
         """
 
-        input_txt = self.input_txt
+        input_txt = self.input_txt.lower()
         if rts:
             rt_pattern = re.compile(r"^(?:RT|rt) \@[a-zA-Z0-9\-\_]+\b")
             input_txt = re.sub(rt_pattern, "", input_txt)
@@ -101,10 +136,15 @@ class CleanText:
             input_txt = re.sub(link_pattern, "", input_txt)
         if spec_chars:
             input_txt = re.sub(r"[^a-zA-Z\u00C0-\u00FF ]", " ", input_txt)
-        input_txt = input_txt.split()
-        output_txt = " ".join(input_txt)
+
+        if stop_words:
+            temp_txt = input_txt.split()
+            temp_txt = [word for word in temp_txt if word not in self.bad_words]
+            output_txt = " ".join(temp_txt)
+
         output_txt = output_txt.replace("xxatsignxx", "@")
         output_txt = output_txt.replace("xxhashtagsignxx", "#")
+
         return output_txt
 
 
@@ -114,12 +154,6 @@ class Features:
         This functions loads the spacy model for spanish.
 
         """
-        # self.nlp_model = Language().from_disk(path_models + 'pipeline')
-
-        self.bad_words = ["de", "que", "la", "los", "el", "las"]
-        ##def remove_names(self, rem_names=False, names_list=[]):
-        # if(rem_names ==True):
-        #    self.bad_words = self.bad_words + names_list
 
     def pos_tags(self, input_txt):
         """
@@ -136,30 +170,29 @@ class Features:
         dict: keys -> tokens, lemmas and part of speech tags.
         i
         """
-        METHOD_NAME = "pos_tags"
+        method_name = "pos_tags"
         self.input_txt = input_txt
         if type(input_txt) != str:
             print("ERROR: Input is not a string.")
-            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             self.input_txt = ""
-        self.bad_words
 
         try:
             out_dict = send_to_model(
                 data={"value": input_txt},
                 ms_models_path=URL_MS_MODELOS + "/models_reg/features/pos_tags",
             )
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             out_dict = {"words": [], "lemmas": [], "pos_tags": []}
 
         return out_dict
 
 
-class Polarity(object):
+class Polarity:
     def __init__(self):
         self.polscore = [-1.0, -0.5, 0, 0.5, 1.0]
 
@@ -170,11 +203,11 @@ class Polarity(object):
             encoded_dict = df_to_formatted(
                 text_list, URL_MS_MODELOS, model_name, model_type
             )
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            raise e
+            raise e_1
         input_ids_b = encoded_dict["input_ids"]
         attention_masks_b = encoded_dict["attention_mask"]
 
@@ -185,11 +218,11 @@ class Polarity(object):
             model_name = "polarity"
             model_type = "tokenize_texts"
             (out,) = df_to_formatted(data, URL_MS_MODELOS, model_name, model_type)
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            raise e
+            raise e_1
 
         sentiment = list(out.argmax(1).numpy())
 
@@ -247,7 +280,7 @@ class Polarity(object):
 
         """
 
-        METHOD_NAME = "batch_polarity"
+        method_name = "batch_polarity"
 
         if isinstance(df_text, list) and all(isinstance(text, str) for text in df_text):
             df_text = pd.DataFrame(columns=["processed_text"], data=df_text)
@@ -262,31 +295,30 @@ class Polarity(object):
                 dict_polscore = {idx: score for idx, score in enumerate(self.polscore)}
                 df_text["polarity"] = df_text["polarity"].map(dict_polscore)
 
-            except Exception as e:
-                print(e)
+            except Exception as e_1:
+                print(e_1)
                 error_1 = sys.exc_info()[0]
                 print(ERR_SYS + str(error_1))
-                print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+                print(f"Class: {self.__str__()}\nMethod: {method_name}")
                 df_text["polarity"] = ""
             return df_text
 
         elif isinstance(df_text, str):
-            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             print(
                 "Must recieve a list of string of pandas DataFrame with strings. returning -100 ..."
             )
             return -100
 
         else:
-            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             print(
                 "Calling polarity method for a non-string variable. returning -100 ..."
             )
             polarity = -100
             return polarity
 
-    def polarity(self, df_text, text_column_name="processed_text"):
-
+    def polarity(self, df_text):
         """
         This function returns the polarity of an input text(s).
 
@@ -301,7 +333,9 @@ class Polarity(object):
 
         Returns
         -------
-        polarity value or pandas DataFrame with a 'polarity' column with the polarity values. (warning, this method returns -100 if input is not a string or if input text is too long.)
+        polarity value or pandas DataFrame with a 'polarity' column with
+        the polarity values. (warning, this method returns -100 if input
+                              is not a string or if input text is too long.)
 
         """
         try:
@@ -309,13 +343,13 @@ class Polarity(object):
             model_type = "polarity"
             polarity = df_to_formatted(df_text, URL_MS_MODELOS, model_name, model_type)
             return polarity
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            raise e
+            raise e_1
 
-    def polarity_only(self, df_text, column_text="message"):
+    def polarity_only(self, df_text):
         """
         This function returns the polarity of an dataframe
 
@@ -339,14 +373,14 @@ class Polarity(object):
             model_type = "polarity_only"
             polarity = df_to_formatted(df_text, URL_MS_MODELOS, model_name, model_type)
             return polarity
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            raise e
+            raise e_1
 
 
-class STTM(object):
+class STTM:
     def __init__(self, df_data, text_column_name="tokenized_text"):
         """
         This function stores the input DataFrame.
@@ -362,9 +396,11 @@ class STTM(object):
         self.df_data = df_data
         self.text_column_name = text_column_name
 
-    def sttm_model(self, K=20, alpha=0.1, beta=0.2, n_iters=100):
+    def sttm_model(self):
         """
-        This function classifies the tokenized texts into groups of similar texts. It creates the 'sttm_group' column with the number of the group that the text was classified into.
+        This function classifies the tokenized texts into groups
+        of similar texts. It creates the 'sttm_group' column with the
+        number of the group that the text was classified into.
 
         Parameters
         ----------
@@ -394,11 +430,11 @@ class STTM(object):
             self.df_data = df_to_formatted(
                 self.df_data, URL_MS_MODELOS, model_name, model_type
             )
-        except Exception as e:
-            print(e)
+        except Exception as e_1:
+            print(e_1)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            raise e
+            raise e_1
         return self.df_data
 
 
