@@ -1,6 +1,4 @@
-import ast
 import json
-import re
 import sys
 import warnings
 from copy import deepcopy
@@ -189,6 +187,7 @@ class MostEffectiveContentTW:
                 self.df_posts_full.twitter_id.isin(account_ids)
             ][
                 [
+                    "twitter_id",
                     "screen_name",
                     "tweet_id",
                     "text",
@@ -202,6 +201,7 @@ class MostEffectiveContentTW:
                 self.df_posts_full.screen_name.isin(account_names)
             ][
                 [
+                    "twitter_id",
                     "screen_name",
                     "tweet_id",
                     "text",
@@ -213,6 +213,7 @@ class MostEffectiveContentTW:
             df_most_eff_posts_tw = deepcopy(
                 self.df_posts_full[
                     [
+                        "twitter_id",
                         "screen_name",
                         "tweet_id",
                         "text",
@@ -243,6 +244,7 @@ class MostEffectiveContentTW:
             print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
             return pd.DataFrame(
                 columns=[
+                    "twitter_id",
                     "screen_name",
                     "tweet_id",
                     "text",
